@@ -380,7 +380,7 @@ main(int argc, char **argv)
   err = clnt_call( clnt, YPPASSWDPROC_UPDATE,
   		 xdr_yppasswd, (char*)&yppasswd,
   		 xdr_int,      (char*)&status,
-  		 &timeout );
+  		 timeout );
 
   if (err) {
       clnt_perrno(err);
